@@ -1,15 +1,17 @@
 """ Base class for the channel of an instrument """
-from typing import (
-    List, Union, Optional, Dict, Sequence,
-    cast, Any, Tuple, Callable,
-)
+from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union, cast
 
-from .base import InstrumentBase, Instrument
-from .parameter import (MultiParameter, ArrayParameter, Parameter,
-    ParamRawDataType, Iterator)
-from ..utils.validators import Validator
-from ..utils.metadata import Metadatable
 from ..utils.helpers import full_class
+from ..utils.metadata import Metadatable
+from ..utils.validators import Validator
+from .base import Instrument, InstrumentBase
+from .parameter import (
+    ArrayParameter,
+    Iterator,
+    MultiParameter,
+    Parameter,
+    ParamRawDataType,
+)
 
 
 class InstrumentChannel(InstrumentBase):
@@ -22,13 +24,6 @@ class InstrumentChannel(InstrumentBase):
 
         name: The name of this channel.
 
-    Attributes:
-
-        parameters (Dict[Parameter]): All the parameters supported by this
-          channel. Usually populated via ``add_parameter``.
-
-        functions (Dict[Function]): All the functions supported by this
-          channel. Usually populated via ``add_function``.
     """
 
     def __init__(self,
@@ -46,7 +41,7 @@ class InstrumentChannel(InstrumentBase):
         # (see https://github.com/QCoDeS/Qcodes/issues/1140 for a nice table)
         # this has been a confusion about names. don't use name but
         # full_name, or short_name.
-        self._name = "{}_{}".format(parent.name, str(name))
+        self._name = f"{parent.name}_{str(name)}"
 
     def __repr__(self) -> str:
         """Custom repr to give parent information"""
@@ -213,7 +208,7 @@ class ChannelList(Metadatable):
                 raise TypeError("All items in this channel list must be of "
                                 "type {}.".format(chan_type.__name__))
 
-    def __getitem__(self, i: Union[int, slice, tuple]) -> \
+    def __getitem__(self, i: Union[int, slice, Tuple[int, ...]]) -> \
             Union['InstrumentChannel', 'ChannelList']:
         """
         Return either a single channel, or a new :class:`ChannelList`
@@ -298,7 +293,7 @@ class ChannelList(Metadatable):
         if self._locked:
             raise AttributeError("Cannot clear a locked channel list")
         # when not locked the _channels seq is a list
-        channels = cast(list, self._channels)
+        channels = cast(List['InstrumentChannel'], self._channels)
         channels.clear()
         self._channel_mapping.clear()
 
@@ -368,6 +363,29 @@ class ChannelList(Metadatable):
         self._channels = cast(List[InstrumentChannel], self._channels)
         self._channels.insert(index, obj)
 
+    def get_channel_by_name(
+        self, *names: str
+    ) -> Union[InstrumentChannel, "ChannelList"]:
+        """
+        Get a channel by name, or a ChannelList if multiple names are given.
+
+        Args:
+            *names: channel names
+        """
+        if len(names) == 0:
+            raise Exception("one or more names must be given")
+        if len(names) == 1:
+            return self._channel_mapping[names[0]]
+        selected_channels = tuple(self._channel_mapping[name] for name in names)
+        return ChannelList(
+            self._parent,
+            self._name,
+            self._chan_type,
+            selected_channels,
+            self._snapshotable,
+            self._paramclass,
+        )
+
     def get_validator(self) -> 'ChannelListValidator':
         """
         Returns a validator that checks that the returned object is a channel
@@ -391,7 +409,7 @@ class ChannelList(Metadatable):
 
     def snapshot_base(self, update: Optional[bool] = True,
                       params_to_skip_update: Optional[Sequence[str]] = None
-                      ) -> Dict:
+                      ) -> Dict[Any, Any]:
         """
         State of the instrument as a JSON-compatible dict (everything that
         the custom JSON encoder class
@@ -476,18 +494,21 @@ class ChannelList(Metadatable):
             else:
                 shapes = tuple(() for _ in self._channels)
 
-            param = self._paramclass(self._channels,
-                                     param_name=name,
-                                     name=f"Multi_{name}",
-                                     names=names,
-                                     shapes=shapes,
-                                     instrument=self._parent,
-                                     labels=labels,
-                                     units=units,
-                                     setpoints=setpoints,
-                                     setpoint_names=setpoint_names,
-                                     setpoint_units=setpoint_units,
-                                     setpoint_labels=setpoint_labels)
+            param = self._paramclass(
+                self._channels,
+                param_name=name,
+                name=f"Multi_{name}",
+                names=names,
+                shapes=shapes,
+                instrument=self._parent,
+                labels=labels,
+                units=units,
+                setpoints=setpoints,
+                setpoint_names=setpoint_names,
+                setpoint_units=setpoint_units,
+                setpoint_labels=setpoint_labels,
+                bind_to_instrument=False,
+            )
             return param
 
         # Check if this is a valid function
@@ -507,7 +528,7 @@ class ChannelList(Metadatable):
         raise AttributeError('\'{}\' object has no attribute \'{}\''
                              ''.format(self.__class__.__name__, name))
 
-    def __dir__(self) -> list:
+    def __dir__(self) -> List[Any]:
         names = list(super().__dir__())
         if self._channels:
             names += list(self._channels[0].parameters.keys())
@@ -523,7 +544,7 @@ class ChannelList(Metadatable):
                                                 max_chars=max_chars)
 
 
-class ChannelListValidator(Validator):
+class ChannelListValidator(Validator[InstrumentChannel]):
     """
     A validator that checks that the returned object is a member of the
     channel list with which the validator was constructed.
@@ -607,7 +628,7 @@ class AutoLoadableInstrumentChannel(InstrumentChannel):
 
     @classmethod
     def _discover_from_instrument(
-            cls, parent: Instrument, **kwargs: Any) -> List[dict]:
+            cls, parent: Instrument, **kwargs: Any) -> List[Dict[Any, Any]]:
         """
         Discover channels on the instrument and return a list kwargs to create
         these channels in memory
@@ -675,7 +696,7 @@ class AutoLoadableInstrumentChannel(InstrumentChannel):
 
     @classmethod
     def _get_new_instance_kwargs(cls, parent: Optional[Instrument] = None,
-                                 **kwargs: Any) -> dict:
+                                 **kwargs: Any) -> Dict[Any, Any]:
         """
         Returns a dictionary which is used as keyword args when instantiating a
         channel
