@@ -1,8 +1,10 @@
 from typing import Any
 
+import numpy as np
+
+from qcodes.instrument.parameter import Parameter
 from qcodes.instrument.visa import VisaInstrument
 from qcodes.utils import validators as vals
-import numpy as np
 
 
 class Weinschel_8320(VisaInstrument):
@@ -13,11 +15,15 @@ class Weinschel_8320(VisaInstrument):
 
     def __init__(self, name: str, address: str, **kwargs: Any):
         super().__init__(name, address, terminator='\r', **kwargs)
-
-        self.add_parameter('attenuation', unit='dB',
-                           set_cmd='ATTN ALL {0:0=2d}',
-                           get_cmd='ATTN? 1',
-                           vals=vals.Enum(*np.arange(0, 60.1, 2).tolist()),
-                           get_parser=float)
+        self.attenuation = Parameter(
+            "attenuation",
+            unit="dB",
+            set_cmd="ATTN ALL {0:0=2d}",
+            get_cmd="ATTN? 1",
+            vals=vals.Enum(*np.arange(0, 60.1, 2).tolist()),
+            instrument=self,
+            get_parser=float,
+        )
+        """Control the attenuation"""
 
         self.connect_message()
