@@ -3,17 +3,23 @@ from math import floor
 
 import pytest
 
-from qcodes.dataset.data_set import (DataSet,
-                                     new_data_set,
-                                     load_by_guid,
-                                     load_by_id,
-                                     load_by_counter,
-                                     load_by_run_spec)
-from qcodes.dataset.descriptions.param_spec import ParamSpecBase
-from qcodes.dataset.descriptions.dependencies import InterDependencies_
-from qcodes.dataset.data_export import get_data_by_id
-from qcodes.dataset.sqlite.queries import get_guids_from_run_spec
+from qcodes.dataset.data_set import (
+    DataSet,
+    load_by_counter,
+    load_by_guid,
+    load_by_id,
+    load_by_run_spec,
+    new_data_set,
+)
+from qcodes.dataset.data_set_info import get_run_attributes
+from qcodes.dataset.descriptions.rundescriber import RunDescriber
 from qcodes.dataset.experiment_container import new_experiment
+from qcodes.dataset.sqlite.queries import (
+    get_experiment_attributes_by_exp_id,
+    get_guids_from_run_spec,
+    get_raw_run_attributes,
+    raw_time_to_str_time,
+)
 
 
 @pytest.mark.usefixtures("experiment")
@@ -71,6 +77,59 @@ def test_load_by_counter():
     assert loaded_ds.completed is True
 
 
+@pytest.mark.usefixtures("experiment")
+def test_get_run_attributes() -> None:
+    name = "test-dataset"
+    ds = new_data_set(name)
+    ds.mark_started()
+    ds.mark_completed()
+    ds.add_metadata("foo", "bar")
+
+    loaded_raw_attrs = get_raw_run_attributes(ds.conn, ds.guid)
+    assert loaded_raw_attrs is not None
+
+    assert loaded_raw_attrs["run_id"] == ds.run_id
+    assert loaded_raw_attrs["counter"] == ds.counter
+    assert loaded_raw_attrs["captured_counter"] == ds.captured_counter
+    assert loaded_raw_attrs["captured_run_id"] == ds.captured_run_id
+    assert loaded_raw_attrs["captured_run_id"] == ds.captured_run_id
+    assert loaded_raw_attrs["experiment"] == get_experiment_attributes_by_exp_id(
+        ds.conn, ds.exp_id
+    )
+    assert loaded_raw_attrs["experiment"]["exp_id"] == ds.exp_id
+    assert loaded_raw_attrs["experiment"]["name"] == ds.exp_name
+    assert loaded_raw_attrs["experiment"]["sample_name"] == ds.sample_name
+    assert loaded_raw_attrs["name"] == name
+    assert loaded_raw_attrs["run_timestamp"] == ds.run_timestamp_raw
+    assert loaded_raw_attrs["completed_timestamp"] == ds.completed_timestamp_raw
+    assert loaded_raw_attrs["parent_dataset_links"] == "[]"
+    assert "interdependencies" in loaded_raw_attrs["run_description"]
+    assert loaded_raw_attrs["snapshot"] is None
+    assert loaded_raw_attrs["metadata"] == {"foo": "bar"}
+
+    loaded_attrs = get_run_attributes(ds.conn, ds.guid)
+    assert loaded_attrs is not None
+
+    assert loaded_attrs["run_id"] == ds.run_id
+    assert loaded_attrs["counter"] == ds.counter
+    assert loaded_attrs["captured_counter"] == ds.captured_counter
+    assert loaded_attrs["captured_run_id"] == ds.captured_run_id
+    assert loaded_attrs["captured_run_id"] == ds.captured_run_id
+    assert loaded_attrs["experiment"] == get_experiment_attributes_by_exp_id(
+        ds.conn, ds.exp_id
+    )
+    assert loaded_attrs["experiment"]["exp_id"] == ds.exp_id
+    assert loaded_attrs["name"] == name
+    assert loaded_attrs["run_timestamp"] == raw_time_to_str_time(ds.run_timestamp_raw)
+    assert loaded_attrs["completed_timestamp"] == raw_time_to_str_time(
+        ds.completed_timestamp_raw
+    )
+    assert loaded_attrs["parent_dataset_links"] == []
+    assert isinstance(loaded_attrs["run_description"], RunDescriber)
+    assert loaded_attrs["snapshot"] is None
+    assert loaded_attrs["metadata"] == {"foo": "bar"}
+
+
 @pytest.mark.usefixtures("empty_temp_db")
 def test_experiment_info_in_dataset():
     exp = new_experiment(name="for_loading", sample_name="no_sample")
@@ -172,43 +231,6 @@ def test_completed_timestamp_with_default_format():
            <= t_after_complete_secs + 1
 
 
-def test_get_data_by_id_order(dataset):
-    """
-    Test that the added values of setpoints end up associated with the correct
-    setpoint parameter, irrespective of the ordering of those setpoint
-    parameters
-    """
-    indepA = ParamSpecBase('indep1', "numeric")
-    indepB = ParamSpecBase('indep2', "numeric")
-    depAB = ParamSpecBase('depAB', "numeric")
-    depBA = ParamSpecBase('depBA', "numeric")
-
-    idps = InterDependencies_(
-        dependencies={depAB: (indepA, indepB), depBA: (indepB, indepA)})
-
-    dataset.set_interdependencies(idps)
-
-    dataset.mark_started()
-
-    dataset.add_results([{'depAB': 12,
-                          'indep2': 2,
-                          'indep1': 1}])
-
-    dataset.add_results([{'depBA': 21,
-                          'indep2': 2,
-                          'indep1': 1}])
-    dataset.mark_completed()
-
-    data = get_data_by_id(dataset.run_id)
-    data_dict = {el['name']: el['data'] for el in data[0]}
-    assert data_dict['indep1'] == 1
-    assert data_dict['indep2'] == 2
-
-    data_dict = {el['name']: el['data'] for el in data[1]}
-    assert data_dict['indep1'] == 1
-    assert data_dict['indep2'] == 2
-
-
 @pytest.mark.usefixtures('experiment')
 def test_load_by_guid(some_interdeps):
     ds = DataSet()
