@@ -1,41 +1,33 @@
 # Since all other tests of data_set and measurements will inevitably also
 # test the sqlite module, we mainly test exceptions and small helper
 # functions here
-from sqlite3 import OperationalError
-from contextlib import contextmanager
 import time
-
-import pytest
-import hypothesis.strategies as hst
-from hypothesis import given
 import unicodedata
-import numpy as np
+from contextlib import contextmanager
 from unittest.mock import patch
 
+import hypothesis.strategies as hst
+import numpy as np
+import pytest
+from hypothesis import given
+
+import qcodes.dataset.descriptions.versioning.serialization as serial
+from qcodes.dataset.data_set import DataSet
+from qcodes.dataset.descriptions.dependencies import InterDependencies_
 from qcodes.dataset.descriptions.param_spec import ParamSpec
 from qcodes.dataset.descriptions.rundescriber import RunDescriber
-from qcodes.dataset.descriptions.dependencies import InterDependencies_
-import qcodes.dataset.descriptions.versioning.serialization as serial
-from qcodes.dataset.sqlite.connection import path_to_dbfile
-from qcodes.dataset.sqlite.database import get_DB_location
 from qcodes.dataset.guids import generate_guid
-from qcodes.dataset.data_set import DataSet
-# pylint: disable=unused-import
-from qcodes.tests.dataset.temporary_databases import \
-    empty_temp_db, experiment, dataset
-from qcodes.tests.dataset.dataset_fixtures import scalar_dataset, \
-    standalone_parameters_dataset
-from qcodes.tests.common import error_caused_by
-# pylint: enable=unused-import
-
-from .helper_functions import verify_data_dict
 
 # mut: module under test
-from qcodes.dataset.sqlite import queries as mut_queries
-from qcodes.dataset.sqlite import query_helpers as mut_help
 from qcodes.dataset.sqlite import connection as mut_conn
 from qcodes.dataset.sqlite import database as mut_db
+from qcodes.dataset.sqlite import queries as mut_queries
+from qcodes.dataset.sqlite import query_helpers as mut_help
+from qcodes.dataset.sqlite.connection import path_to_dbfile
+from qcodes.dataset.sqlite.database import get_DB_location
+from qcodes.tests.common import error_caused_by
 
+from .helper_functions import verify_data_dict
 
 _unicode_categories = ('Lu', 'Ll', 'Lt', 'Lm', 'Lo', 'Nd', 'Pc', 'Pd', 'Zs')
 
@@ -83,12 +75,10 @@ def test_atomic_raises(experiment):
 
     bad_sql = '""'
 
-    # it seems that the type of error raised differs between python versions
-    # 3.6.0 (OperationalError) and 3.6.3 (RuntimeError)
-    # -strange, huh?
-    with pytest.raises((OperationalError, RuntimeError)):
+    with pytest.raises(RuntimeError) as excinfo:
         with mut_conn.atomic(conn):
             mut_conn.transaction(conn, bad_sql)
+    assert error_caused_by(excinfo, "syntax error")
 
 
 def test_insert_many_values_raises(experiment):
@@ -99,10 +89,13 @@ def test_insert_many_values_raises(experiment):
                                     values=[[1], [1, 3]])
 
 
-def test_get_metadata_raises(experiment):
-    with pytest.raises(RuntimeError) as excinfo:
-        mut_queries.get_metadata(experiment.conn, 'something', 'results')
-    assert error_caused_by(excinfo, "no such column: something")
+def test_get_non_existing_metadata_returns_none(experiment):
+    assert (
+        mut_queries.get_data_by_tag_and_table_name(
+            experiment.conn, "something", "results"
+        )
+        is None
+    )
 
 
 @given(table_name=hst.text(max_size=50))
@@ -133,8 +126,7 @@ def test_get_dependents(experiment):
 
     deps = mut_queries._get_dependents(experiment.conn, run_id)
 
-    layout_id = mut_queries._get_layout_id(experiment.conn,
-                                  'y', run_id)
+    layout_id = mut_queries._get_layout_id(experiment.conn, "y", run_id)
 
     assert deps == [layout_id]
 
@@ -200,7 +192,7 @@ def test_update_runs_description(dataset):
             mut_queries.update_run_description(
                 dataset.conn, dataset.run_id, idesc)
 
-    desc = serial.to_json_for_storage(RunDescriber((InterDependencies_())))
+    desc = serial.to_json_for_storage(RunDescriber(InterDependencies_()))
     mut_queries.update_run_description(dataset.conn, dataset.run_id, desc)
 
 
@@ -208,7 +200,7 @@ def test_runs_table_columns(empty_temp_db):
     """
     Ensure that the column names of a pristine runs table are what we expect
     """
-    colnames = mut_queries.RUNS_TABLE_COLUMNS.copy()
+    colnames = list(mut_queries.RUNS_TABLE_COLUMNS)
     conn = mut_db.connect(get_DB_location())
     query = "PRAGMA table_info(runs)"
     cursor = conn.cursor()
@@ -218,11 +210,15 @@ def test_runs_table_columns(empty_temp_db):
     assert colnames == []
 
 
-@pytest.mark.filterwarnings("ignore:get_data")
 def test_get_data_no_columns(scalar_dataset):
     ds = scalar_dataset
-    ref = mut_queries.get_data(ds.conn, ds.table_name, [])
+    with pytest.warns(None) as record:
+        ref = mut_queries.get_data(ds.conn, ds.table_name, [])
+
     assert ref == [[]]
+    assert len(record) == 2
+    assert str(record[0].message).startswith("The function <get_data>")
+    assert str(record[1].message).startswith("get_data")
 
 
 def test_get_parameter_data(scalar_dataset):
@@ -233,17 +229,15 @@ def test_get_parameter_data(scalar_dataset):
 
     assert len(data.keys()) == len(input_names)
 
-    expected_names = {}
-    expected_names['param_3'] = ['param_0', 'param_1', 'param_2',
-                                 'param_3']
-    expected_shapes = {}
-    expected_shapes['param_3'] = [(10 ** 3,)] * 4
+    expected_names = {"param_3": ["param_0", "param_1", "param_2", "param_3"]}
+    expected_shapes = {"param_3": [(10 ** 3,)] * 4}
 
-    expected_values = {}
-    expected_values['param_3'] = [np.arange(10000 * a, 10000 * a + 1000)
-                                  for a in range(4)]
-    verify_data_dict(data, None, input_names, expected_names,
-                     expected_shapes, expected_values)
+    expected_values = {
+        "param_3": [np.arange(10000 * a, 10000 * a + 1000) for a in range(4)]
+    }
+    verify_data_dict(
+        data, None, input_names, expected_names, expected_shapes, expected_values
+    )
 
 
 def test_get_parameter_data_independent_parameters(
@@ -259,21 +253,22 @@ def test_get_parameter_data_independent_parameters(
 
     assert len(data.keys()) == len(expected_toplevel_params)
 
-    expected_names = {}
-    expected_names['param_1'] = ['param_1']
-    expected_names['param_2'] = ['param_2']
-    expected_names['param_3'] = ['param_3', 'param_0']
+    expected_names = {
+        "param_1": ["param_1"],
+        "param_2": ["param_2"],
+        "param_3": ["param_3", "param_0"],
+    }
 
-    expected_shapes = {}
-    expected_shapes['param_1'] = [(10 ** 3,)]
-    expected_shapes['param_2'] = [(10 ** 3,)]
-    expected_shapes['param_3'] = [(10 ** 3,)] * 2
-
-    expected_values = {}
-    expected_values['param_1'] = [np.arange(10000, 10000 + 1000)]
-    expected_values['param_2'] = [np.arange(20000, 20000 + 1000)]
-    expected_values['param_3'] = [np.arange(30000, 30000 + 1000),
-                                  np.arange(0, 1000)]
+    expected_shapes = {
+        "param_1": [(10 ** 3,)],
+        "param_2": [(10 ** 3,)],
+        "param_3": [(10 ** 3,)] * 2,
+    }
+    expected_values = {
+        "param_1": [np.arange(10000, 10000 + 1000)],
+        "param_2": [np.arange(20000, 20000 + 1000)],
+        "param_3": [np.arange(30000, 30000 + 1000), np.arange(0, 1000)],
+    }
 
     verify_data_dict(data, None, expected_toplevel_params, expected_names,
                      expected_shapes, expected_values)
@@ -308,21 +303,26 @@ def test_atomic_creation(experiment):
     def just_throw(*args):
         raise RuntimeError("This breaks adding metadata")
 
-    # first we patch add_meta_data to throw an exception
+    # first we patch add_data_to_dynamic_columns to throw an exception
     # if create_data is not atomic this would create a partial
     # run in the db. Causing the next create_run to fail
-    with patch('qcodes.dataset.sqlite.queries.add_meta_data', new=just_throw):
-        x = ParamSpec('x', 'numeric')
-        t = ParamSpec('t', 'numeric')
-        y = ParamSpec('y', 'numeric', depends_on=['x', 't'])
-        with pytest.raises(RuntimeError,
-                           match="Rolling back due to unhandled exception")as e:
-            mut_queries.create_run(experiment.conn,
-                                   experiment.exp_id,
-                                   name='testrun',
-                                   guid=generate_guid(),
-                                   parameters=[x, t, y],
-                                   metadata={'a': 1})
+    with patch(
+        "qcodes.dataset.sqlite.queries.add_data_to_dynamic_columns", new=just_throw
+    ):
+        x = ParamSpec("x", "numeric")
+        t = ParamSpec("t", "numeric")
+        y = ParamSpec("y", "numeric", depends_on=["x", "t"])
+        with pytest.raises(
+            RuntimeError, match="Rolling back due to unhandled exception"
+        ) as e:
+            mut_queries.create_run(
+                experiment.conn,
+                experiment.exp_id,
+                name="testrun",
+                guid=generate_guid(),
+                parameters=[x, t, y],
+                metadata={"a": 1},
+            )
     assert error_caused_by(e, "This breaks adding metadata")
     # since we are starting from an empty database and the above transaction
     # should be rolled back there should be no runs in the run table
@@ -353,23 +353,73 @@ def test_atomic_creation(experiment):
         assert len(runs) == 1
 
 
-def test_set_run_timestamp(experiment):
+def test_set_run_timestamp(dataset):
 
-    ds = DataSet()
-
-    assert ds.run_timestamp_raw is None
+    assert dataset.run_timestamp_raw is None
+    assert dataset.completed_timestamp_raw is None
 
     time_now = time.time()
     time.sleep(1)  # for slower test platforms
-    mut_queries.set_run_timestamp(ds.conn, ds.run_id)
+    mut_queries.set_run_timestamp(dataset.conn, dataset.run_id)
 
-    assert ds.run_timestamp_raw > time_now
+    assert dataset.run_timestamp_raw is not None
+    assert dataset.run_timestamp_raw > time_now
+    assert dataset.completed_timestamp_raw is None
 
     with pytest.raises(RuntimeError, match="Rolling back due to unhandled "
                                            "exception") as ei:
-        mut_queries.set_run_timestamp(ds.conn, ds.run_id)
+        mut_queries.set_run_timestamp(dataset.conn, dataset.run_id)
 
     assert error_caused_by(ei, ("Can not set run_timestamp; it has already "
                                 "been set"))
 
-    ds.conn.close()
+
+def test_set_run_timestamp_explicit(dataset):
+
+    assert dataset.run_timestamp_raw is None
+    assert dataset.completed_timestamp_raw is None
+
+    time_now = time.time()
+    time.sleep(1)  # for slower test platforms
+    mut_queries.set_run_timestamp(dataset.conn, dataset.run_id, time_now)
+
+    assert dataset.run_timestamp_raw == time_now
+    assert dataset.completed_timestamp_raw is None
+
+    with pytest.raises(
+        RuntimeError, match="Rolling back due to unhandled " "exception"
+    ) as ei:
+        mut_queries.set_run_timestamp(dataset.conn, dataset.run_id)
+
+    assert error_caused_by(ei, "Can not set run_timestamp; it has already " "been set")
+
+
+def test_mark_run_complete(dataset):
+
+    assert dataset.run_timestamp_raw is None
+    assert dataset.completed_timestamp_raw is None
+
+    time_now = time.time()
+    mut_queries.set_run_timestamp(dataset.conn, dataset.run_id)
+    assert dataset.run_timestamp_raw is not None
+    assert dataset.completed_timestamp_raw is None
+    time.sleep(1)  # for slower test platforms
+    mut_queries.mark_run_complete(dataset.conn, dataset.run_id)
+    assert dataset.run_timestamp_raw is not None
+    assert dataset.completed_timestamp_raw is not None
+    assert dataset.completed_timestamp_raw > time_now
+
+
+def test_mark_run_complete_explicit_time(dataset):
+
+    assert dataset.run_timestamp_raw is None
+    assert dataset.completed_timestamp_raw is None
+
+    mut_queries.set_run_timestamp(dataset.conn, dataset.run_id)
+    time_now = time.time()
+    time.sleep(1)  # for slower test platforms
+    mut_queries.mark_run_complete(dataset.conn, dataset.run_id, time_now)
+
+    assert dataset.completed_timestamp_raw == time_now
+
+    mut_queries.mark_run_complete(dataset.conn, dataset.run_id)
